@@ -10,7 +10,10 @@ class Response(ResponseType):
     
     def getOrigin(self):
         try: 
-            return self.url.split(".")[1]
+            split = self.url.split(".")
+            domain = split[1]
+            TLD = split.split("/")[0]
+            return domain + "." + TLD
         except:
             return None
     
